@@ -457,7 +457,7 @@ class DagsterInstance:
                 step_keys_to_execute=step_keys_to_execute,
             )
 
-        return self.get_or_create_run(
+        return self.create_run(
             pipeline_name=pipeline_def.name,
             run_id=run_id,
             environment_dict=environment_dict,
@@ -601,8 +601,15 @@ class DagsterInstance:
         pipeline_snapshot=None,
         execution_plan_snapshot=None,
     ):
-        # The last usage of this method is in dagster-airflow. When the usage is removed, this method
-        # should be deleted.
+        # The usage of this method is limited to dagster-airflow, specifically in Dagster
+        # Operators that are executed in Airflow. Because a common workflow in Airflow is to
+        # retry dags from arbitrary tasks, we need any node to be capable of creating a
+        # PipelineRun.
+        #
+        # The try-except DagsterRunAlreadyExists block handles the race when multiple "root" tasks
+        # simultaneously execute self._run_storage.add_run(pipeline_run). When this happens, only
+        # one task succeeds in creating the run, while the others get DagsterRunAlreadyExists
+        # error; at this point, the failed tasks try again to fetch the existing run.
         # https://github.com/dagster-io/dagster/issues/2412
 
         pipeline_run = self._construct_run_with_snapshots(
@@ -620,7 +627,7 @@ class DagsterInstance:
             execution_plan_snapshot=execution_plan_snapshot,
         )
 
-        if self.has_run(pipeline_run.run_id):
+        def get_run():
             candidate_run = self.get_run_by_id(pipeline_run.run_id)
 
             field_diff = _check_run_equality(pipeline_run, candidate_run)
@@ -634,7 +641,13 @@ class DagsterInstance:
                 )
             return candidate_run
 
-        return self._run_storage.add_run(pipeline_run)
+        if self.has_run(pipeline_run.run_id):
+            return get_run()
+
+        try:
+            return self._run_storage.add_run(pipeline_run)
+        except DagsterRunAlreadyExists:
+            return get_run()
 
     def add_run(self, pipeline_run):
         return self._run_storage.add_run(pipeline_run)
@@ -778,7 +791,7 @@ class DagsterInstance:
         This method delegates to the ``RunLauncher``, if any, configured on the instance, and will
         call its implementation of ``RunLauncher.launch_run()`` to begin the execution of the
         specified run. Runs should be created in the instance (e.g., by calling
-        ``DagsterInstance.get_or_create_run()``) *before* this method is called, and
+        ``DagsterInstance.create_run()``) *before* this method is called, and
         should be in the ``PipelineRunStatus.NOT_STARTED`` state.
 
         Args:
@@ -798,6 +811,9 @@ class DagsterInstance:
     def end_schedule(self, repository, schedule_name):
         return self._scheduler.end_schedule(self, repository, schedule_name)
 
+    def running_job_count(self, repository_name, schedule_name):
+        return self._scheduler.running_job_count(repository_name, schedule_name)
+
     def scheduler_debug_info(self):
         from dagster.core.scheduler import SchedulerDebugInfo, ScheduleStatus
 
@@ -806,32 +822,25 @@ class DagsterInstance:
         schedule_info = self.all_schedules_info()
         schedules = []
         for repository_name, schedule in schedule_info:
-            if (
-                schedule.status == ScheduleStatus.RUNNING
-                and not self._scheduler.is_scheduler_job_running(repository_name, schedule.name)
+            if schedule.status == ScheduleStatus.RUNNING and not self.running_job_count(
+                repository_name, schedule.name
             ):
                 errors.append(
                     "Schedule {schedule_name} is set to be running, but the scheduler is not "
-                    "running the schedule. Run `dagster schedule up` to resolve".format(
-                        schedule_name=schedule.name
-                    )
+                    "running the schedule.".format(schedule_name=schedule.name)
                 )
-            elif (
-                schedule.status == ScheduleStatus.STOPPED
-                and self._scheduler.is_scheduler_job_running(repository_name, schedule.name)
+            elif schedule.status == ScheduleStatus.STOPPED and self.running_job_count(
+                repository_name, schedule.name
             ):
                 errors.append(
                     "Schedule {schedule_name} is set to be stopped, but the scheduler is still running "
-                    "the schedule. Run `dagster schedule up` to resolve".format(
-                        schedule_name=schedule.name
-                    )
+                    "the schedule.".format(schedule_name=schedule.name)
                 )
 
-            if self._scheduler.is_scheduler_job_running(repository_name, schedule.name) > 1:
+            if self.running_job_count(repository_name, schedule.name) > 1:
                 errors.append(
                     "Duplicate jobs found: More than one job for schedule {schedule_name} are "
-                    "running on the scheduler.  "
-                    "Run `dagster schedule up` to resolve".format(schedule_name=schedule.name)
+                    "running on the scheduler.".format(schedule_name=schedule.name)
                 )
 
             schedule_info = {
@@ -891,5 +900,8 @@ class DagsterInstance:
 
         self._schedule_storage.wipe()
 
-    def log_path_for_schedule(self, repository, schedule_name):
-        return self._scheduler.get_log_path(self, repository, schedule_name)
+    def logs_directory_for_schedule(self, repository, schedule_name):
+        return self._scheduler.get_logs_directory(self, repository, schedule_name)
+
+    def logs_path_for_schedule(self, repository, schedule_name):
+        return self._scheduler.get_logs_path(self, repository, schedule_name)
